* ---------------------------------------------------------------------------- *
* Draw Figure 6: pre-reform differences in hazard functions                    *
* ---------------------------------------------------------------------------- *


** prepare file to store results

	qui drop _all
	qui set obs 1
	qui gen t=.
	qui save "$datapath\\hazards.dta", replace

** parameters in estimation

	global lb = 1
	global ub = 181
	global b0 = 25

** loop over groups to estimate hazard

	forvalues g=1/5{
		qui use "$datapath\\men_jul96mar98.dta", clear
		qui ta G if G~=0, g(G)
		qui keep if G`g'==1 & age>19
		qui count
		global N`g' = r(N)
		qui adaptiveh
		qui gen t=_n
		qui keep if t<182
		qui gen group=`g'
		qui keep t group h0 hob ob obsmooth Ln
		qui append using "$datapath\\hazards.dta"
		qui save "$datapath\\hazards.dta", replace
	}

** reshape data

	qui drop if t==.
	qui keep if group<.
	qui reshape wide ob obsmooth h0 hob Ln, i(t) j(group)
	qui sort t

** calculate asymptotic variance of hazard estimates

	forvalues g=1/5 {
		qui gen q`g'     = 1 if inrange(t,obsmooth`g'[1],t[_N]-obsmooth`g'[_N])
		qui replace q`g' = t/obsmooth`g'[1] if t<obsmooth`g'[1]
		qui replace q`g' = (t[_N]-t)/obsmooth`g'[_N] if t>t[_N]-obsmooth`g'[_N]
		qui gen Vq`g'    = 12 * (3*q`g'^2-3*q`g'+2) / ( 5 * (q`g'+1)^3 )
		qui gen aV`g'    = Vq`g' * hob`g' / (${N`g'}*obsmooth`g'*Ln`g')
	}

** draw graphs

	global t2 "oct97 vs sep97"
	global t3 "oct97 vs aug97"
	global t4 "oct97 vs oct96"
	global t5 "oct97 vs sep97+oct96"
	forvalues g=2/5 {
		qui gen d`g' = hob1-hob`g'
		qui gen lbd`g' = d`g'-1.96*sqrt(aV1+aV`g')
		qui gen ubd`g' = d`g'+1.96*sqrt(aV1+aV`g')
		twoway line d`g' lbd`g' ubd`g' t if inrange(t,90,181), ///
		    yline(0) graphregion(fcolor(white)) ///
			xtitle("days since inflow") lpattern(solid dash dash) ///
			lcolor(navy navy navy) ti("${t`g'}") legend(off) ///
			name(g`g', replace) nodraw
	}
	graph combine g2 g3 g4 g5, ycommon rows(2) graphregion(fcolor(white))


