* ---------------------------------------------------------------------------- *
* Draw Figure 7: pre-reform differences in survival functions                  *
* ---------------------------------------------------------------------------- *

* load data

	qui use "$datapath\\men_jul96mar98.dta", clear
	qui keep if age>19

* construct comparison groups

	global P98  = mdy(1,1,1998)
	global NP98 = mdy(4,1,1998)

	qui gen g1C = ((PF==0 & inrange(sue,$NP98-61, $NP98+29-61))  | (PF==1 & inrange(sue,$P98-61, $P98+29-61 )))
	qui gen g2C = ((PF==0 & inrange(sue,$NP98-91, $NP98+29-91))  | (PF==1 & inrange(sue,$P98-91, $P98+29-91 )))
	qui gen g3C = ((PF==0 & inrange(sue,$NP98-121,$NP98+29-121)) | (PF==1 & inrange(sue,$P98-121,$P98+29-121)))
	qui gen g4C = ((PF==0 & inrange(sue,$NP98-151,$NP98+29-151)) | (PF==1 & inrange(sue,$P98-151,$P98+29-151)))
	qui gen g5C = ((PF==0 & inrange(sue,$NP98-181,$NP98+29-181)) | (PF==1 & inrange(sue,$P98-181,$P98+29-181)))

	qui gen g1T = ((PF==0 & inrange(sue,$NP98-31, $NP98+29-31))  | (PF==1 & inrange(sue,$P98-31, $P98+29-31 )))
	qui gen g2T = ((PF==0 & inrange(sue,$NP98-61, $NP98+29-61))  | (PF==1 & inrange(sue,$P98-61, $P98+29-61 )))
	qui gen g3T = ((PF==0 & inrange(sue,$NP98-91, $NP98+29-91))  | (PF==1 & inrange(sue,$P98-91, $P98+29-91 )))
	qui gen g4T = ((PF==0 & inrange(sue,$NP98-121,$NP98+29-121)) | (PF==1 & inrange(sue,$P98-121,$P98+29-121)))
	qui gen g5T = ((PF==0 & inrange(sue,$NP98-151,$NP98+29-151)) | (PF==1 & inrange(sue,$P98-151,$P98+29-151)))

* estimate survival functions

	qui gen t=_n

	forvalues g=1/5 {

		local maxD = 30*`g'

		qui count if g`g'T == 1
		local totT = r(N)
		qui count if g`g'C == 1
		local totC = r(N)

		qui cap drop S`g'T
		qui cap drop S`g'C
		qui cap drop N`g'T
		qui cap drop N`g'C
		qui gen S`g'T = .
		qui gen S`g'C = .
		qui gen N`g'T = .
		qui gen N`g'C = .

		forvalues i=0/`maxD' {
			qui count if g`g'T==1 & dur>`i'
			qui replace S`g'T = r(N)/`totT' if t==`i'
			qui replace N`g'T = r(N) if t==`i'

			qui count if g`g'C==1 & dur>`i'
			qui replace S`g'C = r(N)/`totC' if t==`i'
			qui replace N`g'C = r(N) if t==`i'

		}

		qui gen se_T`g' = sqrt(S`g'T*(1-S`g'T)/(N`g'T-1))
		qui gen lb_T`g' = S`g'T-1.96*se_T`g'
		qui gen ub_T`g' = S`g'T+1.96*se_T`g'

		qui gen se_C`g' = sqrt(S`g'C*(1-S`g'C)/(N`g'C-1))
		qui gen lb_C`g' = S`g'C-1.96*se_C`g'
		qui gen ub_C`g' = S`g'C+1.96*se_C`g'

	}
	
* draw graph

	twoway line S2T lb_T2 ub_T2 S2C lb_C2 ub_C2 t if t<61,  ///
		xtitle(days since inflow) ytitle(survival rates) xlab(0 30 60 90 120 150) ///
		ti(Panel A) subtitle(Inflow in Feb98 (treatment) vs Jan98 (comparison)) ///
		legend(label(1 "treatment group") label(4 "comparison group") order(1 4) rows(1)) ///
		graphregion(fcolor(white)) lpattern(solid dash dash solid dash dash) ///
		lcolor(navy navy navy lavender lavender lavender) name(m2, replace) nodraw
	twoway line S3T lb_T3 ub_T3 S3C lb_C3 ub_C3 t if t<91,  ///
		xtitle(days since inflow) ytitle(survival rates) xlab(0 30 60 90 120 150) ///
		ti(Panel B) subtitle(Inflow in Jan98 (treatment) vs Dec97 (comparison)) ///
		legend(label(1 "treatment group") label(4 "comparison group") order(1 4) rows(1)) ///
		graphregion(fcolor(white)) lpattern(solid dash dash solid dash dash) ///
		lcolor(navy navy navy lavender lavender lavender) name(m3, replace) nodraw
	twoway line S4T lb_T4 ub_T4 S4C lb_C4 ub_C4 t if t<121, ///
		xtitle(days since inflow) ytitle(survival rates) xlab(0 30 60 90 120 150) ///
		ti(Panel C) subtitle(Inflow in Dec97 (treatment) vs Nov97 (comparison)) ///
		legend(label(1 "treatment group") label(4 "comparison group") order(1 4) rows(1)) ///
		graphregion(fcolor(white)) lpattern(solid dash dash solid dash dash) ///
		lcolor(navy navy navy lavender lavender lavender) name(m4, replace) nodraw
	twoway line S5T lb_T5 ub_T5 S5C lb_C5 ub_C5 t if t<151, ///
		xtitle(days since inflow) ytitle(survival rates) xlab(0 30 60 90 120 150) ///
		ti(Panel D) subtitle(Inflow in Nov97 (treatment) vs Oct97 (comparison)) ///
		legend(label(1 "treatment group") label(4 "comparison group") order(1 4) rows(1)) ///
		graphregion(fcolor(white)) lpattern(solid dash dash solid dash dash) ///
		lcolor(navy navy navy lavender lavender lavender) name(m5, replace) nodraw
	grc1leg m2 m3 m4 m5, pos(6) rows(2) graphregion(fcolor(white)) ycommon



