* ---------------------------------------------------------------------------- *
* Draw Figure 8: continuous time estimates of effect of ND at 6 months         *
* ---------------------------------------------------------------------------- *

** load routines

drop _all
global b0=20

** load parameters for estimation 

	global date = mdy(9,30,1997)     // date separating the two groups
	global day1=182                  // time interval over which to calculate effects
	global dayN=211

** hazard for the control group: sept cohort

	qui use "$datapath\men_jul96mar98.dta", replace
	qui keep if G==2 & age6m>19          // sep97 cohort
	local grp "c"

	forvalues days=$day1/$dayN {
		global lb   = `days'         // bounds for observations
		global ub   = 450
		global mini = $lb            // bounds to compute (smoothed) bdw
		global maxi = int($lb+$b0+1)
		global pt   = $lb            // point of interest
		qui adaptiveh_bs
		global h`grp'`days'  = ${h$pt}
		global ob`grp'`days' = $obpt
		qui count if dur>=$lb
		global aV`grp'`days' = 24*${h`grp'`days'}/(5*r(N)*${ob`grp'`days'}) 
		di `days'
	}

** hazard for the treatment group: oct cohort

	qui use "$datapath\men_jul96mar98.dta", replace
	qui keep if G==1 & age6m>19	     // oct97 cohort
	local grp "t"

	forvalues days=$day1/$dayN {
		global lb   = `days'         // bounds for observations
		global ub   = 450
		global mini = $lb            // bounds to compute (smoothed) bdw
		global maxi = int($lb+$b0+1)
		global pt   = $lb            // point of interest
		qui adaptiveh_bs
		global h`grp'`days'  = ${h$pt}
		global ob`grp'`days' = $obpt
		qui count if dur>=$lb
		global aV`grp'`days' = 24*${h`grp'`days'}/(5*r(N)*${ob`grp'`days'}) 
		di `days'
	}

** store information

	forvalues days=$day1/$dayN {
		global aVr`days' = ${aVt`days'}/(${ht`days'}^2) ///
		                 + ${aVc`days'}*(${ht`days'}^2)/(${hc`days'}^4)
		global aVd`days' = ${aVt`days'} + ${aVc`days'}
	}
	
	global totN=$dayN-$day1+1
	global variables "hc ht obc obt aVc aVt aVr aVd"

	qui drop _all
	qui set obs $totN
	qui gen n=_n+$day1-1
	foreach var of global variables {
		qui cap drop `var'
		qui gen `var'=.
		forvalues days=$day1/$dayN {
			qui replace `var'=${`var'`days'} if n==`days'
		}
	}
	
** plot graph

	qui sort n
	qui gen diff  = ht-hc
	qui gen ratio = ht/hc
	qui gen lbdiff  = diff-1.96*sqrt(aVd)
	qui gen ubdiff  = diff+1.96*sqrt(aVd)
	qui gen lbratio = ratio-1.96*sqrt(aVr)
	qui gen ubratio = ratio+1.96*sqrt(aVr)

	twoway line diff lbdiff ubdiff n, yline(0) graphregion(fcolor(white)) ///
	            lpattern(solid dash dash) lcolor(navy navy navy) ///
				ti("Difference in local hazard rates") xtitle("days since inflow") ///
				legend(off) name(diff, replace) nodraw
	twoway line ratio lbratio ubratio n, yline(1) graphregion(fcolor(white)) ///
	            lpattern(solid dash dash) lcolor(navy navy navy) ///
				ti("Ratio of local hazard rates") xtitle("days since inflow") ///
				name(ratio, replace) legend(off) nodraw
	graph combine diff ratio
