* ---------------------------------------------------------------------------- *
* Draw Figure 9: anticipation effects                                          *
* ---------------------------------------------------------------------------- *


** load routines and parameters

	global dtafile "$datapath\men_jan96mar98.dta"
	global b0=20
	global day1=120
	global dayN=172
	global censor189=1


** estimate harad rates and their variances

	forvalues days=$day1/$dayN {

		global dateNPF = mdy(3,31,1998)-`days'
		global datePF  = mdy(12,31,1997)-`days'
		global lb   = `days'                         // bounds for observation window
		global ub   = 450
		global mini = $lb				             // bounds to compute (smoothed) bdw
		global maxi = int($lb+$b0+1)
		global pt   = $lb                            // point of interest
		
		** control group: completing `days' during march 98 or dec 97
		qui use "$dtafile", clear
		qui keep if age>19
		qui gen durrc = (PF==0)*min(dur,mdy(4,1,1998)-sue)        ///    // right censored duration
		              + (PF==1)*min(dur,mdy(1,1,1998)-sue)
		qui gen rc    = (durrc<dur)		                                 // indicator for right censored duration
		qui keep if (PF==0 & inrange(sue,$dateNPF-29,$dateNPF)) | ///
		            (PF==1 & inrange(sue,$datePF-29,$datePF))
		qui adaptiveh_rc_bs
		global hc`days'   = max(${h$pt},0)
		global obc`days'  = $ob
		global obsc`days' = $obpt
		qui count if dur>=$lb
		global aVc`days'  = 24*${hc`days'}/(5*r(N)*${obsc`days'}) 

		** treatment group: completing `days' during april 98 or jan 98
		qui use "$dtafile", clear
		qui keep if age>19
		qui gen durrc = (PF==0)*min(dur,mdy(4,1,1998)-sue)          ///  // right censored duration
		              + (PF==1)*min(dur,mdy(1,1,1998)-sue)
		qui gen rc    = (durrc<dur)		                                 // indicator for right censored duration		
		qui keep if (PF==0 & inrange(sue,$dateNPF+1,$dateNPF+30)) | ///
		            (PF==1 & inrange(sue,$datePF+1,$datePF+30))
		qui adaptiveh_bs
		global ht`days'   = max(${h$pt},0)
		global obt`days'  = $ob
		global obst`days' = $obpt
		qui count if dur>=$lb
		global aVt`days'  = 24*${ht`days'}/(5*r(N)*${obst`days'}) 

		di `days'
	}

	forvalues days=$day1/$dayN {
		global aVr`days' = ${aVt`days'}/(${ht`days'}^2) ///
		                 + ${aVc`days'}*(${ht`days'}^2)/(${hc`days'}^4)
		global aVd`days' = ${aVt`days'} + ${aVc`days'}
	}

	
** calculate differences in hazards

	global totN=$dayN-$day1+1
	global variables "hc ht obc obt obsc obst aVc aVt aVr aVd"
	qui drop _all
	qui set obs $totN
	qui gen n=_n+$day1-1
	foreach var of global variables {
		cap drop `var'
		qui gen `var'=.
		forvalues days=$day1/$dayN {
			qui replace `var'=${`var'`days'} if n==`days'
		}
	}
	
	qui sort n
	qui gen diff  = ht-hc
	qui gen lbdiff = diff-1.96*sqrt(aVd)
	qui gen ubdiff = diff+1.96*sqrt(aVd)
	label var n "days since inflow"
	label var diff "NDYP effect: difference"

** draw graph of differences
	
	twoway line diff lbdiff ubdiff n if n>123, yline(0) ///
		lpattern(solid dash dash) lcolor(navy navy navy) legend(off) ///
		graphregion(fcolor(white)) ytitle("effect in differences") 


		