* ---------------------------------------------------------------------------- *
* Table 4: discrete time estimate of the effect of NDYP                        *
* ---------------------------------------------------------------------------- *


** Estimation routine
** ------------------

	cap program drop discrete
	program define discrete

		local days = 182

		** calculate effect
		qui use "$datapath\lixo.dta", clear
		qui sum leave`days'p if groupT==1 & dur>`days'-1
		global T = r(mean)
		local NT = r(N)
		qui sum leave`days'p if groupC==1 & dur>`days'-1
		global C = r(mean)
		global N = r(N)+`NT'
		global diff6m = ${T}-${C}

		** bootstrap SE
		set seed 165
		forvalues i=1/500 {
			qui use "$datapath\lixo.dta", clear
			qui bsample
			qui sum leave`days'p if groupT==1 & dur>`days'-1
			global T = r(mean)
			qui sum leave`days'p if groupC==1 & dur>`days'-1
			global C = r(mean)
			global diff`i' = ${T}-${C}
			di `i'
		}

		qui drop _all
		qui set obs 500
		qui gen i=_n
		qui gen diff=.
		forvalues i=1/500 {
			qui replace diff = ${diff`i'} if i==`i'
		}
		
	end



** ATS at 6 months duration on prob of leaving JSA within 1 month: 20-24 yo
** ------------------------------------------------------------------------

* prepare data

	drop _all
	use "${datapath}\men_jan96mar98.dta", replace
	keep if age>19

	gen leave182p = inrange(dur,182,182+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-212,mdy(4,30,1998)-212)) | (PF==1 & inrange(sue,mdy(1,1,1998)-212,mdy(1,30,1998)-212)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-182,mdy(4,30,1998)-182)) | (PF==1 & inrange(sue,mdy(1,1,1998)-182,mdy(1,30,1998)-182)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate

	qui discrete
	qui sum 
*	di $N
	global d6m  = $diff6m
	global se6m = r(sd)
	global N6m  = $N



** Placebo effect: ATS at 6 months duration 1 year earlier, 20-24 yo
** -----------------------------------------------------------------

* prepare data

	drop _all
	use "${datapath}\men_jan96mar98.dta", replace
	keep if age>19

	gen leave182p = inrange(dur,182,182+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1997)-212,mdy(4,30,1997)-212)) | (PF==1 & inrange(sue,mdy(1,1,1997)-212,mdy(1,30,1997)-212)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1997)-182,mdy(4,30,1997)-182)) | (PF==1 & inrange(sue,mdy(1,1,1997)-182,mdy(1,30,1997)-182)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate

	qui discrete
	qui sum 
*	di $N
	global d6m_1  = $diff6m
	global se6m_1 = r(sd)
	global N6m_1  = $N



** Placebo effect: ATS at 6 months duration for older workers, 25-29 yo
** --------------------------------------------------------------------

* prepare data

	drop _all
	use "${datapath}\men_jan96mar98_25to30.dta", replace
	keep if age<30

	gen leave182p = inrange(dur,182,182+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-212,mdy(4,30,1998)-212)) | (PF==1 & inrange(sue,mdy(1,1,1998)-212,mdy(1,30,1998)-212)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-182,mdy(4,30,1998)-182)) | (PF==1 & inrange(sue,mdy(1,1,1998)-182,mdy(1,30,1998)-182)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate

	qui discrete
	qui sum 
*	di $N
	global d6m_25p  = $diff6m
	global se6m_25p = r(sd)
	global N6m_25p  = $N
	

** -----------------------------------------------------------------------------
** display estimates 

di _newline ///
   "6 months after inflow ", _column(25) $d6m,  _column(35) $d6m_1,  _column(45) $d6m_25p  _newline ///
                             _column(25) $se6m, _column(35) $se6m_1, _column(45) $se6m_25p _newline ///
                             _column(25) $N6m,  _column(35) $N6m_1,  _column(45) $N6m_25p  _newline 
