* ---------------------------------------------------------------------------- *
* Table 6: discrete time estimate of the anticipation effect of NDYP           *
* ---------------------------------------------------------------------------- *


** Estimation routine
** ------------------

	cap program drop discrete
	program define discrete

		local days = $d

		** calculate effect
		qui use "$datapath\lixo.dta", clear
		sum leave`days'p if groupT==1 & dur>`days'-1
		global T = r(mean)
		local NT = r(N)
		sum leave`days'p if groupC==1 & dur>`days'-1
		global C = r(mean)
		global N = r(N)+`NT'
		global diff6m = ${T}-${C}

		** bootstrap SE
		set seed 165
		forvalues i=1/500 {
			qui use "$datapath\lixo.dta", clear
			qui bsample
			qui sum leave`days'p if groupT==1 & dur>`days'-1
			global T = r(mean)
			qui sum leave`days'p if groupC==1 & dur>`days'-1
			global C = r(mean)
			global diff`i' = ${T}-${C}
			di `i'
		}

		qui drop _all
		qui set obs 500
		qui gen i=_n
		qui gen diff=.
		forvalues i=1/500 {
			qui replace diff = ${diff`i'} if i==`i'
		}
		
	end


** -----------------------------------------------------------------------------
** Effects 4 months after inflow
** -----------------------------------------------------------------------------

	global d = 122

** ATS on prob of leaving JSA within 1 month: 20-24 yo
** ---------------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98.dta", replace
	qui keep if age>19
	qui gen leave122p = inrange(dur,122,122+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-152,mdy(4,30,1998)-152)) | (PF==1 & inrange(sue,mdy(1,1,1998)-152,mdy(1,30,1998)-152)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-122,mdy(4,30,1998)-122)) | (PF==1 & inrange(sue,mdy(1,1,1998)-122,mdy(1,30,1998)-122)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d4m  = $diff6m
	global se4m = r(sd)
	global N4m  = $N
	

** Placebo effect: ATS 1 year earlier, 20-24 yo
** --------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98.dta", replace
	qui keep if age>19
	qui gen leave122p  = inrange(dur,122,122+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1997)-152,mdy(4,30,1997)-152)) | (PF==1 & inrange(sue,mdy(1,1,1997)-152,mdy(1,30,1997)-152)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1997)-122,mdy(4,30,1997)-122)) | (PF==1 & inrange(sue,mdy(1,1,1997)-122,mdy(1,30,1997)-122)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d4m_1  = $diff6m
	global se4m_1 = r(sd)
	global N4m_1  = $N

	
** Placebo effect: ATS for older workers, 25-29 yo
** -----------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98_25to30.dta", replace
	qui keep if age<30
	qui gen leave122p  = inrange(dur,122,122+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-152,mdy(4,30,1998)-152)) | (PF==1 & inrange(sue,mdy(1,1,1998)-152,mdy(1,30,1998)-152)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-122,mdy(4,30,1998)-122)) | (PF==1 & inrange(sue,mdy(1,1,1998)-122,mdy(1,30,1998)-122)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d4m_25p  = $diff6m
	global se4m_25p = r(sd)
	global N4m_25p  = $N
	
	
	
** -----------------------------------------------------------------------------
** Effects 5 months after inflow
** -----------------------------------------------------------------------------
	
	global d = 152
	
** ATS on prob of leaving JSA within 1 month: 20-24 yo
** ---------------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98.dta", replace
	qui keep if age>19
	qui gen leave152p = inrange(dur,152,152+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-182,mdy(4,30,1998)-182)) | (PF==1 & inrange(sue,mdy(1,1,1998)-182,mdy(1,30,1998)-182)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-152,mdy(4,30,1998)-152)) | (PF==1 & inrange(sue,mdy(1,1,1998)-152,mdy(1,30,1998)-152)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d5m  = $diff6m
	global se5m = r(sd)
	global N5m  = $N
	

** Placebo effect: ATS 1 year earlier, 20-24 yo
** --------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98.dta", replace
	qui keep if age>19
	qui gen leave152p  = inrange(dur,152,152+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1997)-182,mdy(4,30,1997)-182)) | (PF==1 & inrange(sue,mdy(1,1,1997)-182,mdy(1,30,1997)-182)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1997)-152,mdy(4,30,1997)-152)) | (PF==1 & inrange(sue,mdy(1,1,1997)-152,mdy(1,30,1997)-152)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d5m_1  = $diff6m
	global se5m_1 = r(sd)
	global N5m_1  = $N

	
** Placebo effect: ATS for older workers, 25-29 yo
** -----------------------------------------------

* prepare data
	qui use "${datapath}\men_jan96mar98_25to30.dta", replace
	qui keep if age<30
	qui gen leave152p  = inrange(dur,152,152+30)
	qui gen groupC = ((PF==0 & inrange(sue,mdy(4,1,1998)-182,mdy(4,30,1998)-182)) | (PF==1 & inrange(sue,mdy(1,1,1998)-182,mdy(1,30,1998)-182)))
	qui gen groupT = ((PF==0 & inrange(sue,mdy(4,1,1998)-152,mdy(4,30,1998)-152)) | (PF==1 & inrange(sue,mdy(1,1,1998)-152,mdy(1,30,1998)-152)))
	qui keep if groupT==1 | groupC==1
	qui save "${datapath}\lixo.dta", replace

* estimate
	qui discrete
	qui sum 
	global d5m_25p  = $diff6m
	global se5m_25p = r(sd)
	global N5m_25p  = $N
	
	
	
** -----------------------------------------------------------------------------
** display estimates 

di _newline ///
   "4 months after inflow ", _column(25) $d4m,  _column(40) $d4m_1,  _column(55) $d4m_25p  _newline ///
                             _column(25) $se4m, _column(40) $se4m_1, _column(55) $se4m_25p _newline ///
                             _column(25) $N4m,  _column(40) $N4m_1,  _column(55) $N4m_25p  _newline ///
   "5 months after inflow ", _column(25) $d5m,  _column(40) $d5m_1,  _column(55) $d5m_25p  _newline ///
                             _column(25) $se5m, _column(40) $se5m_1, _column(55) $se5m_25p _newline ///
                             _column(25) $N5m,  _column(40) $N5m_1,  _column(55) $N5m_25p  
