* ---------------------------------------------------------------------------- *
* Constructs main data for men & saves new stata file juvos0105_m.dta          *
* ---------------------------------------------------------------------------- *

clear
set mem 1000m
use "$datapath\esrc0501.dta", clear

* variable storing codes for Unit of Delivery (UoD) 
qui do "$dopath\UoD.do"
label variable UoD "units of delivery"

* pathfinder indicator (PF)
gen PF=1*(UoD==144 | UoD==106 | UoD==103 | UoD==102 | UoD==81 | UoD==82 | UoD==120 | UoD==121 | UoD==57 | UoD==74 | UoD==46 | UoD==9 | UoD==29 | UoD==2 | UoD==27 | UoD==11)
label variable PF "pathfinder"

* gender
replace sex="1" if sex=="M"
replace sex="2" if sex=="F"
destring sex, replace
label define sex 1 "male" 2 "female"
label values sex sex

* Drop women
drop if sex==2

* destination on leaving ND (dest)
#delimit ;
gen int dest = 	1*(leavmkr=="A")  + 2*(leavmkr=="B")  + 3*(leavmkr=="C")  + 4*(leavmkr=="D")  + 5*(leavmkr=="E")  + 6*(leavmkr=="F") + 
			    7*(leavmkr=="G")  + 8*(leavmkr=="H")  + 9*(leavmkr=="I")  + 10*(leavmkr=="J") + 11*(leavmkr=="K") + 12*(leavmkr=="L") + 
			    13*(leavmkr=="M") + 14*(leavmkr=="N") + 15*(leavmkr=="P") + 16*(leavmkr=="Q") + 17*(leavmkr=="R") + 18*(leavmkr=="S") +
			    19*(leavmkr=="T") + 20*(leavmkr=="V") + 21*(leavmkr=="X"); 
replace dest = 22 if etd<d(1aug1996);
label define dest 0 "still alive" 1 "ceased claiming" 2 "found work" 3 "gone abroad" 4 "claimed another benefit" 5 "full-time educ" 
			      6 "unknown reason" 7 "deceased" 8 "failed to attend" 9 "approved training" 10 "retired" 11 "automatic credits" 
			      12 "new claim review" 13 "transfer to gov training scheme" 14 "jobseeker works > 16hrs" 
			      15 "jobseeker claims back-to-work bonus" 16 "claimed incapacity benefit" 17 "claimed IS" 
			      18 "defective claim" 19 "in prison" 20 "attending court" 21 "?" 22 "claim ends before aug1996", modify;
label values dest dest;
label variable dest "destination";
#delimit cr
drop leavmkr

* date variables (months and weeks)
gen etdd = day(etd)
gen etdm = month(etd)
gen etdy = year(etd)
gen etdw = week(etd)
gen sued = day(sue)
gen suem = month(sue)
gen suey = year(sue)
gen suew = week(sue)
gen per_suem = mofd(sue) 
gen per_etdm = mofd(etd)
gen per_suew = wofd(sue)
gen per_etdw = wofd(etd)

* spell duration 
gen time_d = etd - sue
gen time_w = per_etdw - per_suew
gen time_m = per_etdm - per_suem
label variable time_d "Spell duration in days"
label variable time_w "Spell duration in weeks"
label variable time_m "Spell duration in months"

* regions
gen int reg1d = int(ubo/1000)
label variable reg1d "Region 1 digit"
label define reg1d 1 "South East" 2 "East Anglia" 3 "South West" 4 "West Midlands" 5 "East Midlands" 6 "Yorkshire and Humberside" 7 "North West" 8 "North" 9 "Wales" 10 "Scotland" 11 "North Ireland"
label values reg1d reg1d

gen int reg2d = int(ubo/100)
label variable reg2d "Region 2 digits"

* occupation
gen int socus1d = int(socus/100)
label variable socus1d "SOC usual - major groups"
label define occ1 0 "unknown" 1 "managers" 2 "professionals" 3 "technical" 4 "administrative" 5 "skill trades" 6 "personal services" 7 "sales and customer services" 8 "machine operatives" 9 "elementary"

gen int socus2d = int(socus/10)
label variable socus2d "SOC usual - minor groups"

* marital status
gen maritalst = 1 if married==3 | married==7
replace maritalst =2 if married==4 | married==5 | married==6
replace maritalst =3 if married==1
replace maritalst =4 if married==2
ta maritalst, g(maritalst)

* unemployment history 
sort esrcid sue
by esrcid: gen numspell = _n -1
label var numspell "Number of unemp spell prev this one"

gen U1y=0
gen U2y=0
gen U3y=0
forvalues sp=1/33 {
	qui replace U1y = `sp' if etd[_n-`sp']> mdy(month(sue),day(sue),year(sue)-1) & esrcid==esrcid[_n-`sp']
	qui replace U2y = `sp' if etd[_n-`sp']> mdy(month(sue),day(sue),year(sue)-2) & esrcid==esrcid[_n-`sp']
	qui replace U3y = `sp' if etd[_n-`sp']> mdy(month(sue),day(sue),year(sue)-3) & esrcid==esrcid[_n-`sp']
}
label var U1y "Number of unemp spell last year"
label var U2y "Number of unemp spell last 2 years"
label var U3y "Number of unemp spell last 3 years"

forvalues y=1/3 {
	forvalues sp=1/10 {
		qui gen timeU`y'y_`sp' = etd[_n-`sp'] - max(mdy(month(sue),day(sue),year(sue)-`y'),sue[_n-`sp']) if U`y'y == `sp'
		forvalues w=1/32 {
			qui replace timeU`y'y_`sp' = timeU`y'y_`sp' + etd[_n-`sp'+`w'] - max(mdy(month(sue),day(sue),year(sue)-`y'),sue[_n-`sp'+`w']) if U`y'y >=`w'+1
		}
	}
	egen timeU`y'y = rowtotal(timeU`y'y_*)
	replace timeU`y'y = timeU`y'y/(365*`y')
	drop timeU`y'y_*
}

label var timeU1y "Proportion of time unemp last year"
label var timeU2y "Proportion of time unemp last 2 years"
label var timeU3y "Proportion of time unemp last 3 years"

replace U1y = 4 if U1y>=4
replace U2y = 4 if U2y>=4
replace U3y = 4 if U3y>=4


** cleaning
gen t = .
replace t = 1 if etd > sue
replace t = 0 if etd==sue
replace t = -1 if etd < sue
replace t = 2 if etd ==.
replace t = 3 if sue==.
ta t
drop if t==-1
* 2 observations deleted
drop t

compress
order esrcid ubo pcdist UoD PF sex married maritalst maritalst? socsght socus   ///
      dob sue sued suem suey ///
      suew per_suem per_suew etd etdd etdm etdy etdw per_etdm per_etdw dest     ///
	  time_d time_w time_m reg1d reg2d socus1d ///
	  socus2d numspell U1y U2y U3y timeU1y timeU2y timeU3y
label var sued "start: day"
label var suem "start: month"
label var suey "start: year"
label var suew "start: week"
label var etdd "end: day"
label var etdm "end: month"
label var etdy "end: year"
label var etdw "end: week"
label var per_suem "start: month (1960jan=1)"
label var per_suew "start: week (1960week1=1)"
label var per_etdm "end: month (1960jan=1)"
label var per_etdw "end: week (1960week1=1)"
label var maritalst "marital status"

label define maritalst 1 "married or cohabiting" 2 "divorded or separated" ///
                       3 "unknown" 4 "single"
label val maritalst maritalst
label var maritalst1 "marital indicator: married or cohabiting"
label var maritalst2 "marital indicator: divorded or separated"
label var maritalst3 "marital indicator: unknown"
label var maritalst4 "marital indicator: single"

save "$datapath\juvos0105_men.dta", replace

