**************************************************************************
** Prepare data to compute local hazard rates keeping only the narrow 	**
**	treatment and comparison groups						**
**************************************************************************

clear
set mem 400m


** cohorts flowing into U between July 96 and March 98 and being
**	19-24 when completing 6 months in U
** -----------------------------------------------------------------------------

clear
use "$datapath\juvos0105_men.dta"

keep if sue >= mdy(7,1,1996) & sue <= mdy(3,31,1998)
drop sued suew per_suem per_suew etdd etdm etdy etdw per_etdm per_etdw

local m=6
gen int date6m = mdy(month(sue)+`m'-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),day(sue),year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24))
replace date6m = mdy(month(sue)+`m'+1-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),1,year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24)) if date`m'm==.
format date6m %d
gen byte age6m = year(date`m'm) - year(dob) - (date`m'm<mdy(month(dob),day(dob),year(date`m'm)))
keep if inrange(age6m,19,24)

gen dur = .
replace dur = etd-sue
label var dur "Duration of unemployment spell in days"
keep if dur>0

gen     G = 1*(inrange(sue,mdy(10,1,1997),mdy(10,30,1997))) + ///
            2*(inrange(sue,mdy(9,1,1997),mdy(9,30,1997)))   + ///
			3*(inrange(sue,mdy(8,1,1997),mdy(8,30,1997)))   + ///
			4*(inrange(sue,mdy(10,1,1996),mdy(10,30,1996))) if PF==0
replace G = 1*(inrange(sue,mdy(7,1,1997),mdy(7,30,1997)))   + ///
            2*(inrange(sue,mdy(6,1,1997),mdy(6,30,1997)))   + ///
			3*(inrange(sue,mdy(5,1,1997),mdy(5,30,1997)))   + ///
			4*(inrange(sue,mdy(7,1,1996),mdy(7,30,1996)))   if PF==1
replace G=. if G==0
label var G "group"
label define G 1 "oct 97 cohort" 2 "sep 97 cohort" 3 "aug 97 cohort" 4 "oct 96 cohort"
label values G G

gen G5 = inlist(G,2,4)
label define G5 1 "sep97+oct96 cohort"
label values G5 G5

save "$datapath\men_jul96mar98.dta", replace



** cohorts flowing into U between January 96 and March 98 and being
**	19-24 when completing 6 months in U
** -----------------------------------------------------------------------------

clear
use "$datapath\juvos0105_men.dta"

keep if sue >= mdy(1,1,1996) & sue <= mdy(3,31,1998)
drop sued suew per_suem per_suew etdd etdm etdy etdw per_etdm per_etdw

local m=6
gen int date6m = mdy(month(sue)+`m'-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),day(sue),year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24))
replace date6m = mdy(month(sue)+`m'+1-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),1,year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24)) if date`m'm==.
format date6m %d
gen byte age6m = year(date`m'm) - year(dob) - (date`m'm<mdy(month(dob),day(dob),year(date`m'm)))
keep if inrange(age6m,19,24)

gen dur = .
replace dur = etd-sue
label var dur "Duration of unemployment spell in days"
keep if dur>0

save "$datapath\men_jan96mar98.dta", replace



** cohorts flowing into U between January 96 and March 98 and being
**	25-30 when completing 6 months in U
** -----------------------------------------------------------------------------

clear
use "$datapath\juvos0105_men.dta"

keep if sue >= mdy(1,1,1996) & sue <= mdy(3,31,1998)
drop sued suew per_suem per_suew etdd etdm etdy etdw per_etdm per_etdw

local m=6
gen int date6m = mdy(month(sue)+`m'-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),day(sue),year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24))
replace date6m = mdy(month(sue)+`m'+1-12*(month(sue)+`m'>12)-12*(month(sue)+`m'>24),1,year(sue)+(month(sue)+`m'>12)+(month(sue)+`m'>24)) if date`m'm==.
format date6m %d
gen byte age6m = year(date`m'm) - year(dob) - (date`m'm<mdy(month(dob),day(dob),year(date`m'm)))
keep if inrange(age6m,25,30)

gen dur = .
replace dur = etd-sue
label var dur "Duration of unemployment spell in days"
keep if dur>0

save "$datapath\men_jan96mar98_25to30.dta", replace

